/// Application.
pub mod app;

/// Terminal events handler.
pub mod event;

/// Widget renderer.
pub mod ui;

pub mod server;

/// Event handler.
pub mod handler;

// Game related structures
pub mod game_logic;

// Constants for the app
pub mod constants;

// Utils methods for the board
pub mod utils;

// Logging
pub mod logging;

// Chess pieces
pub mod pieces;

// Configuration
pub mod config;

// Skin
pub mod skin;

// Lichess
pub mod lichess;

// Sound effects
pub mod sound;
